@@ -208,19 +208,24 @@ void FullBackgroundWidget::clearScreensavers()
     }
 }
 
-void FullBackgroundWidget::onSessionStatusChanged(uint status)
+int FullBackgroundWidget::onSessionStatusChanged(uint status)
 {
     qDebug() << "session status changed: " << status;
     if(status != SESSION_IDLE)
     {
         //当前session没有处于空闲状态
-        return;
+        return -1;
     }
     qDebug() << "onSessionStatusChanged - screenStatus: " << screenStatus;
 
+    if(!configuration->xscreensaverActivatedWhenIdle())
+    {
+	return -1;
+    }
+
     if(screenStatus & SCREEN_SAVER)
     {
-        return;
+        return -1;
     }
     else if(screenStatus & SCREEN_LOCK)
     {
@@ -241,6 +246,7 @@ void FullBackgroundWidget::onSessionStatusChanged(uint status)
             showScreensaver();
         }
     }
+    return 0;
 }
 
 void FullBackgroundWidget::onGlobalKeyPress(const QString &key)
@@ -305,8 +311,3 @@ void FullBackgroundWidget::onPrepareForSleep(bool sleep)
         }
     }
 }
-
-bool FullBackgroundWidget::getIdleActivated()
-{
-    return configuration->xscreensaverActivatedWhenIdle();
-}
